<?php

namespace Drupal\browser_development\Processing;

/**
 * Class FileSystemStructure.
 *
 * @package Drupal\browser_development\Processing
 */
class FileSystemStructure {

  /**
   * Global array that holds all relevant paths.
   *
   * @var array
   *   Sets global path.
   */
  public $globalFilePathArray = [
    'public_path' => 'public://browser-development/',
    'css_directory' => 'css',
    'css_name' => 'browser-development.css',
    'scss_directory' => 'scss',
  ];


  /**
   * File system full path.
   *
   * @var string
   *   Finds absolute path for CSS directory.
   */
  public $absolutePath;

  /**
   * Customers CSS styles.
   */
  public function __construct() {
    $this->getAbsolutePath();
    $this->createFileAndDirectoryStructure();
  }

  /**
   * Gets Absolute Path for CSS file creation.
   */
  private function getAbsolutePath() {

    $this->absolutePath = \Drupal::service('file_system')->realpath(
            $this->globalFilePathArray['public_path']);
  }

  /**
   * Creates public directory for CSS file if needed .
   */
  private function createFileAndDirectoryStructure() {

    $public = $this->globalFilePathArray['public_path'];
    $css = $this->globalFilePathArray['css_directory'];
    $file = $this->globalFilePathArray['css_name'];
    $scss = $this->globalFilePathArray['scss_directory'];

    if (!is_dir($public)) {
      $fileSystem = \Drupal::service('file_system');
      $fileSystem->mkdir($public, 0775);
      $fileSystem->mkdir($public . $css, 0775);
      $fileSystem->mkdir($public . $scss, 0775);
      $path = $public . DIRECTORY_SEPARATOR . $css . $file;
      $fileOpen = fopen($path, "wb");
      fwrite($fileOpen, "{}");
      fclose($fileOpen);
    }
  }

}
